@@ -99,12 +99,12 @@ SkypeContact::SkypeContact(SkypeAccount *account, const QString &id, Kopete::Met
 
 	d->callContactAction = new KAction( this );
 	d->callContactAction->setText( i18n ("Call contact") );
-	d->callContactAction->setIcon( (KIcon("skype_call") ) );
+	d->callContactAction->setIcon( (KIcon("voicecall") ) );
 	connect(d->callContactAction, SIGNAL(triggered()), SLOT(call()));
 
 	d->authorizeAction = new KAction( this );
 	d->authorizeAction->setText( i18n ("(Re)send Authorization To") );
-	d->authorizeAction->setIcon( (KIcon("skype_contact_unknown") ) );
+	d->authorizeAction->setIcon( (KIcon("mail-forward") ) );
 	connect(d->authorizeAction, SIGNAL(triggered()), SLOT(authorize()));
 
 	d->disAuthorAction = new KAction( this );
@@ -114,7 +114,7 @@ SkypeContact::SkypeContact(SkypeAccount *account, const QString &id, Kopete::Met
 
 	d->blockAction = new KAction( this );
 	d->blockAction->setText( i18n("Block contact") );
-	d->blockAction->setIcon( (KIcon("skype_blockcontact") ) );
+	d->blockAction->setIcon( (KIcon("dialog-cancel") ) );
 	connect(d->blockAction, SIGNAL(triggered()), SLOT(block()));
 
 	statusChanged();//This one takes care of disabling/enabling this action depending on the user's status.
